@@ -62,29 +62,27 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"globals_defs_m.html",
-"globals_i.html",
-"group__pw__client__node.html#ga8f467593dff291edaac0f46531c23aed",
-"group__pw__impl__core.html#ga32f8301c7a43a4c4d418add1e71642a2",
-"group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0",
-"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47",
-"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
-"group__pwtest.html#gadf579902bf3375a739c90fe2aaf8fd89",
-"group__spa__debug.html#ga43da221712a4457ff34457555d39b214",
-"group__spa__keys.html#ga93f7f32803291d2334ff345690f7bc27",
-"group__spa__node.html#ga7345b7229cf2cf9e60cf142cd6c8c536",
-"group__spa__param.html#ga90558703b75bd503aab2fe68032bcccd",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca7de85ac83fa367961cfe400f7da4eb39",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa1a4e465f86a51b88d564e11faf6f5c65",
-"group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26",
-"group__spa__string.html",
-"iter_8h.html",
-"page_spa_pod.html#autotoc_md139",
-"structpw__endpoint__info.html#a1b2b450d001a613908596afb785c9bf6",
-"structpw__module.html",
-"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952",
-"structspa__io__sequence.html#ab6a424dad012da97efc02bfa77ed57d9",
-"structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0"
+"group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
+"group__pw__global.html#gaf901fcdcb9d2059370fdd9d6ad188c3f",
+"group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67",
+"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59",
+"group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b",
+"group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0",
+"group__spa__dbus.html#ga86263eb7e15c01e44c67b4b92c777a45",
+"group__spa__keys.html#ga397212748e5208c2727994b89ab56b04",
+"group__spa__node.html#ga4057156d1eaf9f13cab72a187735ad65",
+"group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca4c1b239852626671b53906f9d9b89e42",
+"group__spa__param.html#ggab89b8affc8ad458b2cc10dd9e8423fe7acb6b47253078f2060df6af90fdedaf27",
+"group__spa__pod.html#ga1d4549904c233c319e9a6222d7781948",
+"group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fab83a47468dd6f92b64b943c4974cf799",
+"hook_8h.html",
+"page_spa_plugins.html",
+"structpw__device.html",
+"structpw__memmap.html",
+"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b",
+"structspa__io__segment.html#ac4988f1d377a80a859eb45771f3317fb",
+"structspa__pod__object.html#a48beaa7536f4c339aac23729c42a64f3"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
